Disclaimer
==========

**Files in this directory must be never reused**.

Author is not responsible for the misuse of this
information. By using this information, you agree
to this disclaimer and act at your own risk.
